@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 Stichting Mapcode Foundation (http://www.mapcode.com)
+ * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -58,7 +58,7 @@ extern "C" {
 #define MAPCODE_SUPPORT_LANGUAGE_UK
 #endif
 
-#define MAPCODE_C_VERSION                   "2.5.2"
+#define MAPCODE_C_VERSION                   "2.5.5"
 #define UWORD                               unsigned short int  // 2-byte unsigned integer.
 
 #define MAX_NR_OF_MAPCODE_RESULTS           22                  // Max. number of results ever returned by encoder (e.g. for 26.904899, 95.138515).
@@ -73,6 +73,18 @@ extern "C" {
 #define MAX_MAPCODE_RESULT_UTF8_LEN         (MAX_MAPCODE_RESULT_ASCII_LEN * 3) // One mapcode character can become at most 3 UTF8characters.
 #define MAX_MAPCODE_RESULT_UTF16_LEN        (MAX_MAPCODE_RESULT_ASCII_LEN)     // Each mapcode character can become one UTF16 word.
 
+// The constants are also exported as variables, to allow other languages to use them.
+extern char* _MAPCODE_C_VERSION;
+extern int _MAX_NR_OF_MAPCODE_RESULTS;
+extern int _MAX_PRECISION_DIGITS;
+extern int _MAX_PROPER_MAPCODE_ASCII_LEN;
+extern int _MAX_ISOCODE_ASCII_LEN;
+extern int _MAX_CLEAN_MAPCODE_ASCII_LEN;
+extern int _MAX_MAPCODE_RESULT_ASCII_LEN;
+extern int _MAX_TERRITORY_FULLNAME_UTF8_LEN;
+extern int _MAX_MAPCODE_RESULT_UTF8_LEN;
+extern int _MAX_MAPCODE_RESULT_UTF16_LEN;
+extern int _MAX_ALPHABETS_PER_TERRITORY;
 
 /**
  * The type Mapcodes hold a number of mapcodes, for example from an encoding call.
@@ -80,7 +92,7 @@ extern "C" {
  * International mapcodes never include a territory ISO3166 code, nor a space.
  */
 typedef struct {
-    int count;                                                              // The number of mapcode results (length of array).
+    int count;                                                               // The number of mapcode results (length of array).
     char mapcode[MAX_NR_OF_MAPCODE_RESULTS][MAX_MAPCODE_RESULT_ASCII_LEN];   // The mapcodes.
 } Mapcodes;
 
@@ -179,8 +191,7 @@ int encodeLatLonToMapcodes(
  *
  * Arguments:
  *      result          - Returned Mapcode. The caller must not allocate or de-allocated this string.
- *                        The resulting string MUST be allocated (and de-allocated) by the caller (contrary to
- *                        encodeLatLonToMapcodes!).
+ *                        The resulting string MUST be allocated (and de-allocated) by the caller.
  *                        The caller should allocate at least MAX_MAPCODE_RESULT_ASCII_LEN characters for the string.
  *      lat             - Latitude, in degrees. Range: -90..90.
  *      lon             - Longitude, in degrees. Range: -180..180.
@@ -201,6 +212,38 @@ int encodeLatLonToSingleMapcode(
         int extraDigits);
 
 
+/**
+ * Encode a latitude, longitude pair (in degrees) to a single Mapcode, selected from all Mapcodes.
+ * This method is offered for languages which have trouble supporting multi-dimensional arrays from C
+ * (like Swift).
+ *
+ * Arguments:
+ *      result          - Returned Mapcode. The caller must not allocate or de-allocated this string.
+ *                        The resulting string MUST be allocated (and de-allocated) by the caller.
+ *                        The caller should allocate at least MAX_MAPCODE_RESULT_ASCII_LEN characters for the string.
+ *      lat             - Latitude, in degrees. Range: -90..90.
+ *      lon             - Longitude, in degrees. Range: -180..180.
+ *      territory       - Territory (e.g. as obtained from getTerritoryCode), used as encoding context.
+ *                        Pass TERRITORY_NONE or TERRITORY_UNKNOWN to get Mapcodes for all territories.
+ *      extraDigits     - Number of extra "digits" to add to the generated mapcode. The preferred default is 0.
+ *                        Other valid values are 1 to 8, which will add extra letters to the mapcodes to
+ *                        make them represent the coordinate more accurately.
+ *      indexOfSelected - Index of selected mapcode. Must be in valid range for number of results.
+ *                        The index is base 0. To fetch all Mapcodes, pass 0 in a first call to retrieve the
+ *                        first Mapcode and the total number of results and iterate over the rest.
+ *
+ * Returns:
+ *      Total number of results available for selection. <=0 if encoding failed, or >0 if it succeeded.
+ */
+int encodeLatLonToSelectedMapcode(
+    char *mapcode,
+    double latDeg,
+    double lonDeg,
+    enum Territory territory,
+    int extraDigits,
+    int indexOfSelected);
+
+
 /**
  * Decode a utf8 or ascii Mapcode to  a latitude, longitude pair (in degrees).
  *
