@@ -1,8 +1,8 @@
 #!/bin/sh
-OPTS="-Wall -Werror -Wextra -Wno-pointer-to-int-cast -fprofile-arcs -ftest-coverage"
+OPTS="-Wall -Wextra -Wno-pointer-to-int-cast -fprofile-arcs -ftest-coverage"
 LIB="../mapcodelib/mapcoder.o"
 
-TEST=`which gcov`
+TEST=$(which gcov)
 if [ "$TEST" = "" ]
 then
     echo "No gcov found on this machine - skipping script..."
@@ -29,5 +29,3 @@ echo "!! -------------------------------------------------------------"
 echo "!! Coverage reports in: *.gcov files"
 echo "!! -------------------------------------------------------------"
 
-echo ""
-echo "Report in: $REPORT"
